Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1059)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/webapps/WebApkBuilder.java

Issue 2064943002: Pass in extra parameters to WebApkBuilder#buildWebApkAsync() (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Merge branch 'master' into webapk_manifest000 Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/webapps/WebApkBuilder.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/webapps/WebApkBuilder.java b/chrome/android/java/src/org/chromium/chrome/browser/webapps/WebApkBuilder.java
index 2f08cd6cbd46dc6461e62a9d3a0d7d7c1a75bdeb..41514368cd1a9e02125c9d5e1fc7b4e8451edd58 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/webapps/WebApkBuilder.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/webapps/WebApkBuilder.java
@@ -12,11 +12,23 @@ import android.graphics.Bitmap;
public interface WebApkBuilder {
/**
* Asynchronously build WebAPK.
* @param startUrl The url that the WebAPK should navigate to when launched from the app list.
* @param scope Navigations from the WebAPK to URLs with sub-origin {@link scope} will stay
* within the WebAPK.
* @param appName Name for the app list.
* @param icon Icon for the app list.
*/
- void buildWebApkAsync(String startUrl, String scope, String appName, Bitmap appIcon);
+ void buildWebApkAsync(String startUrl, String scope, String name, String shortName,
+ String iconUrl, Bitmap icon, int displayMode, int orientation, long themeColor,
+ long backgroundColor, String manifestUrl);
}

Powered by Google App Engine
@@ -12,11 +12,23 @@ import android.graphics.Bitmap;
/**
* Asynchronously build WebAPK.
- * @param startUrl The url that the WebAPK should navigate to when launched from the app list.
- * @param scope Navigations from the WebAPK to URLs with sub-origin {@link scope} will stay
- * within the WebAPK.
- * @param appName Name for the app list.
- * @param icon Icon for the app list.
+ * @param startUrl The url that the WebAPK should navigate to when launched from the app
+ * list.
+ * @param scope Navigations from the WebAPK to URLs with sub-origin {@link scope} will
+ * stay within the WebAPK.
+ * @param name "name" from the Web Manifest.
+ * @param shortName "short_name" from the Web Manifest.
+ * @param iconUrl Url of the icon for the app list. Url of the favicon if the Web
+ * Manifest does not specify an icon.
+ * @param icon Icon for the app list. Generated icon or favicon if the Web Manifest
+ * does not specify an icon.
+ * @param displayMode "display" from the Web Manifest.
+ * @param orientation "orientation" from the Web Manifest.
+ * @param themeColor "theme_color" from the Web Manifest.
+ * @param backgroundColor "background_color" from the Web Manifest.
+ * @param manifestUrl The URL of the Web Manifest.
*/
This is Rietveld 408576698